ControlFlowEscapeType class final

Identifies control flow jumps/escapes that affect functional extraction.

This is a closed set of constants, not an enum: new values may be added in minor releases. switch statements and expressions over it must include a default (_) arm.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Identifier of this value (earlyReturn, ...), used as the JSON type value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited