SignatureSynthesizer class

Synthesizes idiomatic Dart method signatures with Dart 3 Records.

Constructors

SignatureSynthesizer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
synthesize({required List<VariableUsage> inputs, required List<VariableUsage> outputs, List<String> typeParameters = const [], String methodName = '_extracted', bool isAsync = false}) String
Generates a proposed function signature from analyzed inputs and outputs.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited