ControlFlowEscape class

Represents a control flow escape found inside an extracted code block.

Constructors

ControlFlowEscape({required ControlFlowEscapeType type, required int line, required String description})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ControlFlowEscapeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited