ControlFlowEscapeType class final
Identifies control flow jumps/escapes that affect functional extraction.
This is a closed set of constants, not an enum: new values may be added in
minor releases. switch statements and expressions over it must include a
default (_) arm.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- closureEscape → const ControlFlowEscapeType
- constructorInitializerEscape → const ControlFlowEscapeType
- earlyReturn → const ControlFlowEscapeType
- loopBreak → const ControlFlowEscapeType
- loopContinue → const ControlFlowEscapeType
- rethrowEscape → const ControlFlowEscapeType
-
values
→ const List<
ControlFlowEscapeType> - All values.
- yieldEscape → const ControlFlowEscapeType