DataFlowResult class
The comprehensive result of data-flow extraction analysis.
Constructors
-
DataFlowResult({required String filePath, required int startLine, required int endLine, required String enclosingDeclaration, required List<
VariableUsage> inputs, required List<VariableUsage> mutations, required List<VariableUsage> outputs, required List<ControlFlowEscape> escapes, required String suggestedSignature, required bool isCleanlyExtractable}) -
const
Properties
- enclosingDeclaration → String
-
final
- endLine → int
-
final
-
escapes
→ List<
ControlFlowEscape> -
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputs
→ List<
VariableUsage> -
final
- isCleanlyExtractable → bool
-
final
-
mutations
→ List<
VariableUsage> -
final
-
outputs
→ List<
VariableUsage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startLine → int
-
final
- suggestedSignature → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited