VariableUsage class
Represents the usage of a variable across data-flow bounds.
Constructors
Properties
- declarationLine → int
-
final
- declarationOffset → int
-
final
- firstMutationLine → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMutated → bool
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
copyWith(
{bool? isMutated, int? firstMutationLine}) → VariableUsage -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited